booleditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# booleditor

class `camelot.view.controls.editors.booleditor.` `BoolEditor`(parent=None, minimum=-2147483648, maximum=2147483647, nullable=True, field_name='boolean', **kwargs)

  Widget for editing a boolean field

class `camelot.view.controls.editors.booleditor.` `TextBoolEditor`(parent=None, yes='Yes', no='No', color_yes=None, color_no=None, **kwargs)

  Parameter : | color_yes: string text-color of the True representation color_no: string text-color of the False representation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus